|    Metrics    |                                                                                     Master                                                                                     |                                                                                  Develop                                                                                 |
|:-------------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|
| CI status     | [![pipeline status](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/badges/master/pipeline.svg)](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/commits/master) | [![pipeline status](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/badges/dev/pipeline.svg)](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/commits/dev) |
| Test coverage | [![coverage report](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/badges/master/coverage.svg)](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/commits/master) | [![coverage report](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/badges/dev/coverage.svg)](https://gitlab.com/redmic-project/device/oag-buoy/buoy-lib/commits/dev) |


